==> vradi-services-0.0.5-sources.jar: com/jurismarches/vradi/services/search/UnsupportedQueryException.java <==
/*
 * *##%
 * Vradi :: Services
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * ##%*
 */
package com.jurismarches.vradi.services.search;

import org.apache.lucene.search.Query;

/**
 * <code>UnsupportedQueryException</code> indicates that a <code>Query</code>
 *  is not supported by the <code>LuceneQueryParser</code>.
 * 
 * @author $Author: schorlet $
 * @version $Revision: 473 $ $Date: 2010-02-06 00:31:12 +0100 (sam., 06 févr. 2010) $
 * @since 0.0.4
 */
public class UnsupportedQueryException extends Exception {

    private static final long serialVersionUID = 1L;

    private String query = null;
    
    public UnsupportedQueryException(String query, Throwable cause) {
        // TODO: remplacer par une clé i18n
        super("unsupported query: " + query, cause);
        this.query = query;
    }
    
    public UnsupportedQueryException(Query query) {
        super("unsupported query: " + query.toString());
    }
    
    public String getQuery() {
        return query;
    }
}

==> vradi-services-0.1.0-sources.jar: com/jurismarches/vradi/services/search/UnsupportedQueryException.java <==
/*
 * *##%
 * Vradi :: Services
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * ##%*
 */
package com.jurismarches.vradi.services.search;

import static org.nuiton.i18n.I18n._;

import org.apache.lucene.search.Query;

/**
 * <code>UnsupportedQueryException</code> indicates that a <code>Query</code>
 *  is not supported by the <code>LuceneQueryParser</code>.
 * 
 * @author $Author: chatellier $
 * @version $Revision: 1111 $ $Date: 2010-06-21 14:05:28 +0200 (lun., 21 juin 2010) $
 * @since 0.0.4
 */
public class UnsupportedQueryException extends Exception {

    /** serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** Query that throw the exception. */
    protected String query = null;
    
    public UnsupportedQueryException(String query, Throwable cause) {
        super(_("Unsupported query: %s", query), cause);
        this.query = query;
    }
    
    public UnsupportedQueryException(Query query) {
        super("unsupported query: " + query.toString());
    }
    
    public String getQuery() {
        return query;
    }
}
